@@ -6,15 +6,15 @@ from apps.notebooks.models import Notebook
 class NotebookSerializer(serializers.ModelSerializer):
     class Meta:
         model = Notebook
-        read_only_fields = ("id", "created_at", "file_updated_at")
+        read_only_fields = ("id", "created_at", "file_updated_at", "hosted_on")
         fields = (
             "id",
             "created_at",
             "file_updated_at",
+            "hosted_on",
             "title",
             "slug",
             "path",
-            "share",
             "params",
             "state",
             "default_view_path",
