@@ -41,7 +41,18 @@ def parse_params(nb, params={}):
 
     no_outputs = True
 
+    mercury_package_imported = False
+
     for cell in nb["cells"]:
+        
+        if not mercury_package_imported:
+            # try to guess if mercury is imported
+            code = cell.get("source", "")
+            if isinstance(code, list):
+                code = "".join(code)
+            if "mercury" in code:
+                mercury_package_imported = True
+
         for output in cell.get("outputs", []):
             if "data" in output and "application/mercury+json" in output["data"]:
                 no_outputs = False
@@ -112,7 +123,7 @@ def parse_params(nb, params={}):
     if params.get("continuous_update") is None:
         params["continuous_update"] = True
     if params.get("static_notebook") is None:
-        params["static_notebook"] = False
+        params["static_notebook"] = not mercury_package_imported
     if params.get("show_sidebar") is None:
         params["show_sidebar"] = True
     if params.get("full_screen") is None:
