@@ -7,14 +7,14 @@ from .manager import WidgetException, WidgetsManager
 
 
 class Numeric:
-    def __init__(self, value=0, min=0, max=10, label="", step=1):
+    def __init__(self, value=0, min=0, max=10, label="", step=1, url_key=""):
         if value < min:
             raise WidgetException("value should be equal or larger than min")
         if value > max:
             raise WidgetException("value should be equal or smaller than max")
 
         self.code_uid = WidgetsManager.get_code_uid("Numeric")
-
+        self.url_key = url_key
         if WidgetsManager.widget_exists(self.code_uid):
             self.numeric = WidgetsManager.get_widget(self.code_uid)
             if self.numeric.min != min:
@@ -71,6 +71,7 @@ class Numeric:
                 "label": self.numeric.description,
                 "model_id": self.numeric.model_id,
                 "code_uid": self.code_uid,
+                "url_key": self.url_key,
             }
             data["application/mercury+json"] = json.dumps(view, indent=4)
             if "text/plain" in data:
